 /*
 * file      : src/edit.c
 * project   : tm
 * with      : Gtk-2
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TM - Edition des heures de travail / Edition of working hours
 * GNU General Public License
 * 
 * This file is part of TM.
 * 
 * TM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * TM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TM.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
	#define gettext_noop(x) (x) 
#endif

#include <gtk/gtk.h>
#include <string.h>
#include <stdlib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_tm/lib.h"
#endif

#include "global.h"
#include "callbacks.h"
#include "configuser.h"



#define MAX_DAY_ADJUST 10

VAR_EDIT VarEdit = {
	FALSE,					// It's ready to edit
	FALSE,					// TRUE IF edit
	TRUE,					// If TRUE then CALL: EditYear_spinbutton_time_value_changed()
	0,					// Annee actuelle en edition
	0,					// Total jours par an
	-1,					// Jour de l'annee ou -1
	NULL,					// Buffer file datas
	NULL,					// (VAR_EDIT_DAY *)g_malloc0( sizeof(VAR_EDIT_DAY) * VarEdit.NbrJoursAnnee )
	NULL					// VAR_EDIT_DAY	*DayAdjust
	};



// 
// 
// 
void edit_set_flag_buttons( void )
{
	guint 	year, month, day;
	
	gtk_calendar_get_date( GTK_CALENDAR(VarCallbacks.Adr_Calendar), &year, &month, &day );
	
	if( TRUE == VarEdit.BoolReady && year == VarEdit.YearEdit ) {
		gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("vbox_saisie")), TRUE );
		gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_export_year")), TRUE );
		gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_init_base_year")), TRUE );
		// gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("label_new_year")), TRUE );
	}
	else {
		gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("vbox_saisie")), FALSE );		
		gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_export_year")), FALSE );	
		gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_init_base_year")), FALSE );	
		// gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("label_new_year")), FALSE );
	}
	draw_year();
}
// 
// 
// 
void edit_set_textview( gchar *Str )
{
	GtkTextBuffer	*Buf = NULL;
	GtkTextIter    Start;
	GtkTextIter    End;
	
	Buf = gtk_text_view_get_buffer( GTK_TEXT_VIEW(VarCallbacks.Adr_textview) );
	gtk_text_buffer_get_bounds (Buf, &Start, &End);
	gtk_text_buffer_delete (Buf, &Start, &End);
	gtk_text_buffer_insert_at_cursor( Buf, Str, -1 );
}
// 
// 
// 
void edit_set_datas_to_spinbuttons( guint p_DayOfYear )
{
	if( NULL != VarEdit.Day ) {
		gint	H, M;
		
		VarEdit.BoolChanged = FALSE;

		H = VarEdit.Day[ p_DayOfYear ].MatinDebut / 60;
		M = VarEdit.Day[ p_DayOfYear ].MatinDebut % 60;
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_h), H );
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_mn), M );
		
		H = VarEdit.Day[ p_DayOfYear ].MatinFin / 60;
		M = VarEdit.Day[ p_DayOfYear ].MatinFin % 60;
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h), H );
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_mn), M );
		
		H = VarEdit.Day[ p_DayOfYear ].SoirDebut / 60;
		M = VarEdit.Day[ p_DayOfYear ].SoirDebut % 60;
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h), H );
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_mn), M );
		
		H = VarEdit.Day[ p_DayOfYear ].SoirFin / 60;
		M = VarEdit.Day[ p_DayOfYear ].SoirFin % 60;
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_h), H );
		gtk_spin_button_set_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_mn), M );
				
		edit_set_textview( VarEdit.Day[ p_DayOfYear ].LongComment->str );
		
		VarEdit.BoolChanged = TRUE;
	}
}
// 
// 
// 
gchar *edit_get_namefile( gchar *p_PathNameFile )
{
	// if( FALSE == libutils_test_dir_exist( Config.PathNameFileBase ) ) {
	// 	gchar	*Ptr = strrchr( Config.PathNameFileBase, '/' );
	if( FALSE == libutils_test_dir_exist( p_PathNameFile ) ) {
		gchar	*Ptr = strrchr( p_PathNameFile, '/' );
		Ptr ++;
		return( (gchar *)Ptr );
	}
	return( (gchar *)NULL );
}
// 
// 
// 
void edit_set_pathnamefile( gchar *PathNameFile )
{
	if( NULL != Config.PathNameFileBase ) {
		g_free( Config.PathNameFileBase ); 
		Config.PathNameFileBase = NULL;
	}
	Config.PathNameFileBase = g_strdup( PathNameFile );
}
// 
// 
// 
gint edit_select_new_year( void )
{
	gint	Day;
	gint	Month;
	gint	Year;
	gint	RetDayOfYear;
	
	RetDayOfYear = libutils_get_DMY( &Day, &Month, &Year );
	
	// SELECTION ACTUELLE
	if( Year == VarEdit.YearEdit ) {
		gtk_calendar_select_month( GTK_CALENDAR(VarCallbacks.Adr_Calendar), Month -1, VarEdit.YearEdit );
		gtk_calendar_select_day( GTK_CALENDAR(VarCallbacks.Adr_Calendar), Day );
	}
	// SELECTION DEBUT DE L'ANNEE
	else {
		gtk_calendar_select_month( GTK_CALENDAR(VarCallbacks.Adr_Calendar), 0, VarEdit.YearEdit );
		gtk_calendar_select_day( GTK_CALENDAR(VarCallbacks.Adr_Calendar), 1 );
	}
	
	return( RetDayOfYear );
}






// 
// 
// 
void on_spinbutton_time_value_changed( GtkSpinButton *spinbutton, gpointer user_data )
{
	guint		Minutes;
	gint		matin_debut;
	gint		matin_fin;
	gint		soir_debut;
	gint		soir_fin;
	gboolean	BoolForce = FALSE;
	
	if( FALSE == VarEdit.BoolChanged ) return;
	
	if( NULL == VarCallbacks.Adr_spinbutton_matin_debut_h ||
	    NULL == VarCallbacks.Adr_spinbutton_matin_debut_mn ||
	    NULL == VarCallbacks.Adr_spinbutton_matin_fin_h ||
	    NULL == VarCallbacks.Adr_spinbutton_matin_fin_mn ||
	    NULL == VarCallbacks.Adr_spinbutton_soir_debut_h ||
	    NULL == VarCallbacks.Adr_spinbutton_soir_debut_mn ||
	    NULL == VarCallbacks.Adr_spinbutton_soir_fin_h ||
	    NULL == VarCallbacks.Adr_spinbutton_soir_fin_mn ) return;
		
	matin_debut  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_h) ) * 60;
	matin_debut += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_mn) );
	
	matin_fin   = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h) ) * 60;
	matin_fin  += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_mn) );
	
	soir_debut  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h) ) * 60;
	soir_debut += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_mn) );
	
	soir_fin    = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_h) ) * 60;
	soir_fin   += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_mn) );
	
	// 
	// RECTIF DES HEURES ET DES MINUTES :
	// LE TEMPS SUIVANT NE PEUT ETRE INFERIEUR AU TEMPS ACTUEL
	// 	matin_debut  matin_fin  soir_debut  soir_fin
	// 
	if( matin_debut > matin_fin ) {
		Minutes = matin_fin = matin_debut;
	} else {
		Minutes = 0;
	}
	// ACTION SUR HEURE
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h),
			Minutes / 60,
			23
			);
	// ACTION SUR MINUTES
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_mn),
			Minutes % 60,
			59
			);

	if( matin_fin > soir_debut ) {
		Minutes = soir_debut = matin_fin;
	} else {
		Minutes = 0;
	}
	// ACTION SUR HEURE
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h),
			Minutes / 60,
			23
			);
	// ACTION SUR MINUTES
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_mn),
			Minutes % 60,
			59
			);

	if( soir_debut  > soir_fin ) {
		Minutes = soir_fin = soir_debut;
	} else {
		Minutes = 0;
	}
	// ACTION SUR HEURE
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_h),
			Minutes / 60,
			23
			);
	// ACTION SUR MINUTES
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_mn),
			Minutes % 60,
			59
			);



	
	
	// AJUSTE LA LIMITE INFERIEURE DE
	// 	MATIN_FIN
	// 	SOIR_DEBUT
	// 	SOIR_FIN
	/*
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h),
			gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_h)),
			23
			);
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h),
			gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h)),
			23
			);
	gtk_spin_button_set_range(
			GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_h),
			gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h)),
			23
			);
	*/
	
	// MATIN DEBUT
	if( spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_h) || spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_mn) ) {
		
		Minutes  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_h) );
		Minutes *= 60;
		Minutes += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_debut_mn) );
		VarEdit.Day[ VarEdit.DayOfYear ].MatinDebut = Minutes;
		
		BoolForce = TRUE;
	}
	
	// MATIN FIN
	else if( spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h) || spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_mn) ) {
		
		Minutes  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_h) );
		Minutes *= 60;
		Minutes += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_matin_fin_mn) );
		VarEdit.Day[ VarEdit.DayOfYear ].MatinFin = Minutes;		
		
		BoolForce = TRUE;
	}
	
	// SOIR DEBUT
	else if( spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h) || spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_mn) ) {
		
		Minutes  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_h) );
		Minutes *= 60;
		Minutes += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_debut_mn) );
		VarEdit.Day[ VarEdit.DayOfYear ].SoirDebut = Minutes;		
		
		BoolForce = TRUE;
	}
	
	// SOIR FIN
	else if( spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_h) || spinbutton == GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_mn) ) {
		
		Minutes  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_h) ) * 60;
		Minutes += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_soir_fin_mn) );
		VarEdit.Day[ VarEdit.DayOfYear ].SoirFin = Minutes;		
		
		BoolForce = TRUE;
	}
	file_save_struct( BoolForce == TRUE ? FORCE_SAVE_FILE : NO_FORCE_SAVE_FILE);
	if( TRUE == BoolForce ) {
		guint	Month = page_get_month();
		file_make_list( Month, Month );	// SELECT MONTH
	}
	draw_year();
}
// 
// 
// 
void on_spinbutton_matin_debut_h_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_matin_debut_h = widget;
}
// 
// 
// 
void on_spinbutton_matin_debut_mn_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_matin_debut_mn = widget;
}
// 
// 
// 
void on_spinbutton_matin_fin_h_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_matin_fin_h = widget;
}
// 
// 
// 
void on_spinbutton_matin_fin_mn_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_matin_fin_mn = widget;
}
// 
// 
// 
void on_spinbutton_soir_debut_h_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_soir_debut_h = widget;
}
// 
// 
// 
void on_spinbutton_soir_debut_mn_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_soir_debut_mn = widget;
}
// 
// 
// 
void on_spinbutton_soir_fin_h_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_soir_fin_h = widget;
}
// 
// 
// 
void on_spinbutton_soir_fin_mn_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_spinbutton_soir_fin_mn = widget;
}
void edit_set_longcomment( void )
{
	gchar         *PtrDummy = NULL;
	GtkTextIter    Start;
	GtkTextIter    End;
	gchar         *Ptr = NULL;
	GtkTextBuffer *Buf = NULL;

	Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (VarCallbacks.Adr_textview));
	gtk_text_buffer_get_bounds (Buf, &Start, &End);

	PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
	Ptr = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
	g_string_append_printf( VarEdit.Day[ VarEdit.DayOfYear ].LongComment, "%s", Ptr );
	g_free (PtrDummy);
	PtrDummy = NULL;
	g_free (Ptr);
	Ptr = NULL;
}
// Signal 'changed' in TextView
// 
void callbacks_texte_changed_in_textview (GtkTextBuffer *textbuffer, gpointer user_data)
{
	if( FALSE == VarEdit.BoolChanged ) return;
	
	// VarCallbacks.Adr_textview
	if( NULL != VarCallbacks.Adr_textview ) {
		
		guint	Month = page_get_month();
		
		if( NULL != VarEdit.Day[ VarEdit.DayOfYear ].LongComment ) {
			g_string_free( VarEdit.Day[ VarEdit.DayOfYear ].LongComment, TRUE );
			VarEdit.Day[ VarEdit.DayOfYear ].LongComment = NULL;
			VarEdit.Day[ VarEdit.DayOfYear ].LongComment = g_string_new( NULL );
		}
		edit_set_longcomment();
		file_save_struct( FORCE_SAVE_FILE );
		file_make_list( Month, Month );	// SELECT MONTH
		draw_year();
	}	
}
// 
// SIGNAL_CHANGED
// void changed_textview (GtkTextBuffer *textbuffer, gpointer user_data) { }
// IN REALIZE:
// g_signal_connect((gpointer) gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)), "changed", G_CALLBACK (changed_textview), NULL);
// 
void on_textview_comment_realize( GtkWidget *widget, gpointer user_data )
{
	VarCallbacks.Adr_textview = widget;

	// Signal 'changed'
	g_signal_connect ((gpointer) gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)),
				"changed",
				G_CALLBACK (callbacks_texte_changed_in_textview),
				NULL);
}
// 
// 
// 
void on_spinbutton_time_by_week_value_changed( GtkSpinButton *spinbutton, gpointer user_data )
{
	if( NULL != VarCallbacks.Adr_spinbutton_time_by_week_h && NULL != VarCallbacks.Adr_spinbutton_time_by_week_mn ) {
		
		guint	Month = page_get_month();
		
		Config.TimeByWeek  = (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_time_by_week_h) );
		Config.TimeByWeek *= 60;
		Config.TimeByWeek += (gint)gtk_spin_button_get_value( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_time_by_week_mn) );
		file_make_list( Month, Month );	// SELECT MONTH
		draw_year();
	}
}
// 
// 
// 
void on_spinbutton_time_by_week_h_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_spin_button_set_value( GTK_SPIN_BUTTON(widget), Config.TimeByWeek / 60 );
	VarCallbacks.Adr_spinbutton_time_by_week_h = widget;
}
// 
// 
// 
void on_spinbutton_time_by_week_mn_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_spin_button_set_value( GTK_SPIN_BUTTON(widget), Config.TimeByWeek % 60 );
	VarCallbacks.Adr_spinbutton_time_by_week_mn = widget;
}
// 
// Retourne DEBUT et FIN de p_month et p_year
// 
void edit_get_base_days_in_month( guint p_month, guint p_year, gint *p_begin, gint *p_end )
{
	GDate	*DateHeap;
	
	// FIXER ANNEE MOIS JOUR
	DateHeap = g_date_new ();
	g_date_set_year( DateHeap, p_year );
	g_date_set_month( DateHeap, p_month +1 );
	g_date_set_day( DateHeap, 1 );
	
	*p_begin = g_date_get_day_of_year( DateHeap );
	*p_end = *p_begin + g_date_get_days_in_month( p_month +1, p_year );
		
	g_date_free( DateHeap );
}
// 
// gint p_IndMonth
// 	0=ALL MONTH, 1=JANVIER .. 12=DECEMBRE
// 
void edit_apply_weeks( gint p_IndMonth )
{
	gint	MatinDebut;
	gint	MatinFin;
	gint	SoirDebut;
	gint	SoirFin;
	gchar	*Comment = NULL;
	gint	Day;
	gint	DayBegin;
	gint	DayEnd;
		
	// ALL THE DAYS OF YEAR
	if( 0 == p_IndMonth ) {
		
		for( Day = 0; Day < VarEdit.NbrJoursAnnee; Day ++ ) {
			
			// 1=Lundi ... 7=Dimanche
			// VarEdit.Day[ Day ].ThisDay
			edit_get_DayAdjust( VarEdit.Day[ Day ].ThisDay -1, &MatinDebut, &MatinFin, &SoirDebut, &SoirFin, &Comment );
			
			VarEdit.Day[ Day ].MatinDebut       = MatinDebut;
			VarEdit.Day[ Day ].MatinFin         = MatinFin;
			VarEdit.Day[ Day ].SoirDebut        = SoirDebut;
			VarEdit.Day[ Day ].SoirFin          = SoirFin;
		}
	} else {
		
		edit_get_base_days_in_month( p_IndMonth -1, VarEdit.YearEdit, &DayBegin, &DayEnd );
		DayBegin --;
		DayEnd --;
		for( Day = DayBegin; Day < DayEnd; Day ++ ) {
			
			// 1=Lundi ... 7=Dimanche
			// VarEdit.Day[ Day ].ThisDay
			edit_get_DayAdjust( VarEdit.Day[ Day ].ThisDay -1, &MatinDebut, &MatinFin, &SoirDebut, &SoirFin, &Comment );
			
			VarEdit.Day[ Day ].MatinDebut       = MatinDebut;
			VarEdit.Day[ Day ].MatinFin         = MatinFin;
			VarEdit.Day[ Day ].SoirDebut        = SoirDebut;
			VarEdit.Day[ Day ].SoirFin          = SoirFin;
		}
	}
	edit_set_datas_to_spinbuttons( VarEdit.DayOfYear );
	file_save_struct( FORCE_SAVE_FILE );
	file_make_list( 0, 11 );		// ALL MONTHS
	draw_year();
}
// 
// 
void edit_set_DayAdjust( gint p_ind, gint p_MatinDebut, gint p_MatinFin, gint p_SoirDebut, gint p_SoirFin, gchar *p_Comment )
{
	if( -1 != p_MatinDebut ) {
		VarEdit.DayAdjust[ p_ind ].MatinDebut = p_MatinDebut;
	}
	else if( -1 != p_MatinFin ) {
		VarEdit.DayAdjust[ p_ind ].MatinFin   = p_MatinFin;
	}
	else if( -1 != p_SoirDebut ) {
		VarEdit.DayAdjust[ p_ind ].SoirDebut  = p_SoirDebut;
	}
	else if( -1 != p_SoirFin ) {
		VarEdit.DayAdjust[ p_ind ].SoirFin    = p_SoirFin;
	}
	
	switch( p_ind ) {
	case 0 :
		if( -1 != p_MatinDebut )	Config.HoursMonday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursMonday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursMonday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursMonday[ 3 ] = p_SoirFin;
		break;
	case 1 :
		if( -1 != p_MatinDebut )	Config.HoursTuesday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursTuesday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursTuesday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursTuesday[ 3 ] = p_SoirFin;
		break;
	case 2 :
		if( -1 != p_MatinDebut )	Config.HoursWednesday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursWednesday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursWednesday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursWednesday[ 3 ] = p_SoirFin;
		break;
	case 3 :
		if( -1 != p_MatinDebut )	Config.HoursThursday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursThursday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursThursday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursThursday[ 3 ] = p_SoirFin;
		break;
	case 4 :
		if( -1 != p_MatinDebut )	Config.HoursFriday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursFriday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursFriday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursFriday[ 3 ] = p_SoirFin;
		break;
	case 5 :
		if( -1 != p_MatinDebut )	Config.HoursSaturday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursSaturday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursSaturday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursSaturday[ 3 ] = p_SoirFin;
		break;
	case 6 :
		if( -1 != p_MatinDebut )	Config.HoursSunday[ 0 ] = p_MatinDebut;
		if( -1 != p_MatinFin )		Config.HoursSunday[ 1 ] = p_MatinFin;
		if( -1 != p_SoirDebut )		Config.HoursSunday[ 2 ] = p_SoirDebut;
		if( -1 != p_SoirFin )		Config.HoursSunday[ 3 ] = p_SoirFin;
		break;
	}
}
// 
// 
// 
void edit_get_DayAdjust( gint p_ind, gint *p_MatinDebut, gint *p_MatinFin, gint *p_SoirDebut, gint *p_SoirFin, gchar **p_Comment )
{
	*p_MatinDebut = VarEdit.DayAdjust[ p_ind ].MatinDebut;
	*p_MatinFin   = VarEdit.DayAdjust[ p_ind ].MatinFin;
	*p_SoirDebut  = VarEdit.DayAdjust[ p_ind ].SoirDebut;
	*p_SoirFin    = VarEdit.DayAdjust[ p_ind ].SoirFin;
}






